@@ -19,7 +19,7 @@ class LinkSubmenu(GObject.GObject, Thunarx.MenuProvider):
     name = _("Link Context-Menu")
 
     description = _(
-        "This plugin adds a context menu "
+        "This plugin adds a context menu item "
         "for creating symbolic links to files."
     )
 
@@ -30,36 +30,26 @@ class LinkSubmenu(GObject.GObject, Thunarx.MenuProvider):
         if len(files) != 1:  # For now only consider single files
             return
 
-        link_menuitem = Thunarx.MenuItem(
-            name="ContextMenu::Link",
-            label=_("Link"),
-            # tooltip="?",
-            icon="link",
-        )
-
-        link_submenu = Thunarx.Menu()
-
-        link_to_this_file_item = Thunarx.MenuItem(
-            name="ContextMenu::Link::ToThisFile",
-            icon="insert-link",
-            label=_("To this directory")
-            if files[0].is_directory()
-            else _("To this file"),
-            tooltip=_(
+        if files[0].is_directory():
+            label = _("Link to this directory")
+            tooltip = _(
                 "Create a link somewhere else pointing to this directory"
             )
-            if files[0].is_directory()
-            else _("Create a link somewhere else pointing to this file"),
+        else:
+            label = _("Link to this file")
+            tooltip = _("Create a link somewhere else pointing to this file")
+
+        link_menuitem = Thunarx.MenuItem(
+            name="ContextMenu::Link",
+            label=label,
+            tooltip=tooltip,
+            icon="insert-link",
         )
-        link_to_this_file_item.connect(
+        link_menuitem.connect(
             "activate",
             self.create_link,
             {"window": window, "files": files},
         )
-        link_submenu.append_item(link_to_this_file_item)
-
-        link_menuitem.set_menu(link_submenu)
-
         return (link_menuitem,)
 
     def create_link(self, item, info):
